# onepiecepredictor Package

pip install onepiecepredictor

A Small package for hyper paramter tuning pipelining and comparing multiple models performance with very little code.

Its a wrapper around sklearn, xgboost, catboost, imblearn packages.

For examples and documentation, please check Examples and Documentation.ipynb notebook file above.